@@ -13,6 +13,13 @@ class Cylinder(Mesh):
         height: float = 1.0,
         **kwargs: Any,
     ) -> None:
+        """Define a Cylinder with given parameters
+
+        Keyword arguments:
+        bottom_radius -- Bottom radius
+        top_radius -- Top radius
+        meridians -- Vertical steps to draw the cylinder
+        height -- Height of the cylinder"""
         super().__init__(**kwargs)
         self._bottom_radius: float = bottom_radius
         self._top_radius: float = top_radius
@@ -21,6 +28,7 @@ class Cylinder(Mesh):
         self.build_cylinder()
 
     def build_cylinder(self) -> bool:
+        """Build the cylinder based on the initial parameters"""
         step_angle = math.radians(360 / self._meridians)
 
         u_step = 1.0 / self._meridians
@@ -49,19 +57,23 @@ class Cylinder(Mesh):
             v4 = 0.0
 
             self.add_triangle(
-                [[x1, y1, -h_2], [x3, y3, -h_2], [x2, y2, h_2]], texcoords=[[u1, v1], [u3, v3], [u2, v2]],
+                [[x1, y1, -h_2], [x3, y3, -h_2], [x2, y2, h_2]],
+                texcoords=[[u1, v1], [u3, v3], [u2, v2]],
             )
 
             self.add_triangle(
-                [[x3, y3, -h_2], [x4, y4, h_2], [x2, y2, h_2]], texcoords=[[u3, v3], [u4, v4], [u2, v2]],
+                [[x3, y3, -h_2], [x4, y4, h_2], [x2, y2, h_2]],
+                texcoords=[[u3, v3], [u4, v4], [u2, v2]],
             )
 
             self.add_triangle(
-                [[x1, y1, -h_2], [0.0, 0.0, -h_2], [x3, y3, -h_2]], texcoords=[[u1, v1], [0.0, 0.0], [u3, v3]],
+                [[x1, y1, -h_2], [0.0, 0.0, -h_2], [x3, y3, -h_2]],
+                texcoords=[[u1, v1], [0.0, 0.0], [u3, v3]],
             )
 
             self.add_triangle(
-                [[x4, y4, h_2], [0.0, 0.0, h_2], [x2, y2, h_2]], texcoords=[[u4, v4], [0.0, 0.0], [u2, v2]],
+                [[x4, y4, h_2], [0.0, 0.0, h_2], [x2, y2, h_2]],
+                texcoords=[[u4, v4], [0.0, 0.0], [u2, v2]],
             )
 
         self.fix_normals()
